@@ -256,26 +256,29 @@ int cell_size;
 int variant_max;
 #define DEFAULT_CELL_SIZE 30000000
 
-int IS_INCELL(int addr){
-	if(addr >= 0 && addr < cell_size)
-	return(1);
-	else
-	return(0);
-} 
+int IS_INCELL(int addr)
+{
+    if (addr >= 0 && addr < cell_size)
+	return (1);
+    else
+	return (0);
+}
 
-int IS_OUTCELL(int addr){
-	if(addr < 0 || addr >= cell_size)
-	return(1);
-	else 
-	return(0);
-}   
+int IS_OUTCELL(int addr)
+{
+    if (addr < 0 || addr >= cell_size)
+	return (1);
+    else
+	return (0);
+}
 
-int IS_ALPHA(int addr){
-	if(addr < variant_max && addr > cell_size)
-	return(1);
-	else 
-	return(0);
-}      
+int IS_ALPHA(int addr)
+{
+    if (addr < variant_max && addr > cell_size)
+	return (1);
+    else
+	return (0);
+}
 
 void alloc_cell(int requested_size)
 {
@@ -290,7 +293,7 @@ void alloc_cell(int requested_size)
 
     heap = cell_area;
     cell_size = requested_size;
-	variant_max = cell_size + VARIANTSIZE;
+    variant_max = cell_size + VARIANTSIZE;
 
 }
 
@@ -299,8 +302,9 @@ void usage()
 {
     printf("List of options:\n");
     printf("-c filename -- NPL starts after reading the file.\n");
+	printf("-d          -- string is double quote.\n");
     printf("-h          -- display help.\n");
-	printf("-m N        -- NPL runs with N(30>=N>=10) mega cells.\n");
+    printf("-m N        -- NPL runs with N(30>=N>=10) mega cells.\n");
     printf("-n          -- NPL runs with network mode.\n");
     printf("-r          -- NPL does not use editable REPL.\n");
     printf("-s filename -- NPL runs file with script mode.\n");
@@ -310,11 +314,10 @@ void usage()
 int main(int argc, char *argv[])
 {
     int ch, input;
-    char *path;
     struct winsize w;
 
     signal(SIGINT, reset);
-	alloc_cell(cell_size);
+    alloc_cell(cell_size);
     init_cell();
     init_builtin();
     init_operator();
@@ -335,11 +338,7 @@ int main(int argc, char *argv[])
 	goto repl;
     }
 
-    path = prolog_file_name("library/startup.pl");
-    if (path)
-	b_consult(list1(makeconst("library/startup.pl")), NIL, 0);
-
-    while ((ch = getopt(argc, argv, "c:s:m:rhvn")) != -1) {
+    while ((ch = getopt(argc, argv, "c:s:m:rhdvn")) != -1) {
 	switch (ch) {
 	case 'c':
 	    b_consult(list1(makeconst(optarg)), NIL, 0);
@@ -358,16 +357,19 @@ int main(int argc, char *argv[])
 	    usage();
 	    exit(EXIT_SUCCESS);
 	case 'm':
-		cell_size = strtol(optarg, NULL, 10) * 1000000;
-		if (cell_size < 10000000 || cell_size > 30000000)
-		    cell_size = DEFAULT_CELL_SIZE;
-		break;
+	    cell_size = strtol(optarg, NULL, 10) * 1000000;
+	    if (cell_size < 10000000 || cell_size > 30000000)
+		cell_size = DEFAULT_CELL_SIZE;
+	    break;
 	case 'n':
 	    printf("N-Prolog runs with network mode.\n");
 	    child_flag = 1;
 	    init_parent();
 	    init_creceiver();
 	    break;
+	case 'd':
+		string_flag = 1;
+		break;
 	default:
 	    usage();
 	    exit(EXIT_FAILURE);
@@ -375,7 +377,8 @@ int main(int argc, char *argv[])
     }
 
     if (init_flag) {
-	printf("N-Prolog Ver %1.2f [%dM cells]\n", VERSION, cell_size/1000000);
+	printf("N-Prolog Ver %1.2f [%dM cells]\n", VERSION,
+	       cell_size / 1000000);
 	init_flag = 0;
     }
 
@@ -461,6 +464,7 @@ void init_repl(void)
     for (i = 0; i <= thread_num; i++) {
 	wp[i] = wp_min[i];
     }
+	open_flag = 0;
     ctrl_c_flag = 0;
     compiled_flag = 0;
     fskip_flag = OFF;
@@ -1186,7 +1190,6 @@ void debugger(int goal, int bindings, int rest)
 	printf("w: write goal\n");
 	printf("@: invoke REPL once\n");
 	printf(";: skip to next REDO port (only in EXIT port)\n");
-	fflush(stdin);
 	goto loop;
     case 'l':
 	leap_point = list3(SLASH, car(goal), makeint(length(goal) - 1));
