@@ -13,7 +13,7 @@ char special[1][1] = { };
 char operator[OPERATOR_NUMBER][5] = {
     { ":-" }, { "-->" }, { "," }, { ";" }, { "?-" }, { "." },
     { "+" }, { "-" }, { "*" }, { "/" }, { "//" }, { "<<" }, { ">>" },
-    { "\\" }, { "/\\" }, { "\\/" }, { "mod" }, { "^" }, { "**" },
+    { "\\" }, { "/\\" }, { "\\/" }, { "mod" }, { "^" }, { "**" }, { "xor" },
 };
 
 char function[FUNCTION_NUMBER][12] = {
@@ -108,7 +108,9 @@ char extended[EXTENDED_NUMBER][30] = {
     { "gpio_read" }, { "gpio_event_request" }, { "gpio_event_wait" },
     { "gpio_event_read" },
     { "gpio_close" }, { "sleep" }, { "usleep" },
-    { "format" },
+    { "format" }, { "gr_open" }, { "gr_close" }, { "gr_pset" },
+	{ "gr_circle" },
+    { "gr_rect" }, { "gr_line" },
 };
 
 static bool in_operator_table(const char *str)
